Python Turtle
:::::::::::::

.. toctree::
   :caption: Python Turtle
   :maxdepth: 3

   intro-HelloLittleTurtles.rst
   OurFirstTurtleProgram.rst
   InstancesAHerdofTurtles.rst
   ObjectInstances.rst
   RepetitionwithaForLoop.rst
   AFewMoreturtleMethodsandObservations.rst
   SummaryOfTurtleMethods.rst
   WPIncrementalProgramming.rst
   WPCommonTurtleErrors.rst
   Exercises.rst
   week1a3.rst
   